# Autogenerated by nbdev

d = { 'settings': { 'allowed_cell_metadata_keys': '',
                'allowed_metadata_keys': '',
                'audience': 'Developers',
                'author': 'algovera',
                'author_email': 'hello@algovera.ai',
                'black_formatting': 'False',
                'branch': 'master',
                'clean_ids': 'True',
                'company_name': 'algovera',
                'copyright': 'algovera.ai',
                'custom_sidebar': 'False',
                'description': 'A python library by Algovera to interact with IPFS and IPFS ecosystem such as the common pinning services',
                'dev_requirements': 'fastai',
                'doc_baseurl': '/ipfspy/',
                'doc_host': 'https://algoveraai.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/AlgoveraAI/ipfspy/tree/master',
                'host': 'github',
                'jupyter_hooks': 'True',
                'keywords': 'ipfs, web3, storage, pinata, estuary',
                'language': 'English',
                'lib_name': 'ipfspy',
                'lib_path': 'ipfspy',
                'license': 'apache2',
                'min_python': '3.6',
                'nbs_path': 'nbs',
                'readme_nb': 'index.ipynb',
                'recursive': 'False',
                'repo_name': 'ipfspy',
                'requirements': 'requests==2.27.1 fastcore pandas ipfshttpclient==0.7.0 dag-cbor fsspec ipfsspec imageio',
                'status': '2',
                'title': 'ipfspy',
                'tst_flags': 'ignoretest',
                'user': 'algovera',
                'version': '0.0.3'},
  'syms': { 'ipfspy.estuaryapi': { 'ipfspy.estuaryapi.add_car': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#add_car',
                                   'ipfspy.estuaryapi.add_cid': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#add_cid',
                                   'ipfspy.estuaryapi.add_content': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#add_content',
                                   'ipfspy.estuaryapi.add_content_path': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#add_content_path',
                                   'ipfspy.estuaryapi.add_data': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#add_data',
                                   'ipfspy.estuaryapi.add_key': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#add_key',
                                   'ipfspy.estuaryapi.add_pin': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#add_pin',
                                   'ipfspy.estuaryapi.create_coll': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#create_coll',
                                   'ipfspy.estuaryapi.est_get_viewer': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#est_get_viewer',
                                   'ipfspy.estuaryapi.get_data': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_data',
                                   'ipfspy.estuaryapi.get_deal_data': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_deal_data',
                                   'ipfspy.estuaryapi.get_deal_logs': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_deal_logs',
                                   'ipfspy.estuaryapi.get_deal_status': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_deal_status',
                                   'ipfspy.estuaryapi.get_failure_logs': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_failure_logs',
                                   'ipfspy.estuaryapi.get_miner_ask': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_miner_ask',
                                   'ipfspy.estuaryapi.get_node_stats': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_node_stats',
                                   'ipfspy.estuaryapi.get_pin': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_pin',
                                   'ipfspy.estuaryapi.get_provider_stats': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#get_provider_stats',
                                   'ipfspy.estuaryapi.list_coll_content': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#list_coll_content',
                                   'ipfspy.estuaryapi.list_colls': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#list_colls',
                                   'ipfspy.estuaryapi.list_content_path': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#list_content_path',
                                   'ipfspy.estuaryapi.list_data': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#list_data',
                                   'ipfspy.estuaryapi.list_deals': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#list_deals',
                                   'ipfspy.estuaryapi.list_pins': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#list_pins',
                                   'ipfspy.estuaryapi.list_providers': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#list_providers',
                                   'ipfspy.estuaryapi.make_deal': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#make_deal',
                                   'ipfspy.estuaryapi.remove_pin': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#remove_pin',
                                   'ipfspy.estuaryapi.replace_pin': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#replace_pin',
                                   'ipfspy.estuaryapi.view_data_cid': 'https://algoveraai.github.io/ipfspy/estuaryapi.html#view_data_cid'},
            'ipfspy.ipfshttpapi': { 'ipfspy.ipfshttpapi.DownloadDir': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#downloaddir',
                                    'ipfspy.ipfshttpapi.DownloadDir.download': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#downloaddir.download',
                                    'ipfspy.ipfshttpapi.IPFSApi': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi',
                                    'ipfspy.ipfshttpapi.IPFSApi.add_items': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.add_items',
                                    'ipfspy.ipfshttpapi.IPFSApi.block_get': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.block_get',
                                    'ipfspy.ipfshttpapi.IPFSApi.block_put': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.block_put',
                                    'ipfspy.ipfshttpapi.IPFSApi.block_rm': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.block_rm',
                                    'ipfspy.ipfshttpapi.IPFSApi.block_stat': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.block_stat',
                                    'ipfspy.ipfshttpapi.IPFSApi.cat_items': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.cat_items',
                                    'ipfspy.ipfshttpapi.IPFSApi.change_gateway_type': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.change_gateway_type',
                                    'ipfspy.ipfshttpapi.IPFSApi.dag_export': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.dag_export',
                                    'ipfspy.ipfshttpapi.IPFSApi.dag_get': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.dag_get',
                                    'ipfspy.ipfshttpapi.IPFSApi.dag_stat': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.dag_stat',
                                    'ipfspy.ipfshttpapi.IPFSApi.get_items': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.get_items',
                                    'ipfspy.ipfshttpapi.IPFSApi.ls_items': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.ls_items',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_chcid': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_chcid',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_cp': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_cp',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_flush': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_flush',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_ls': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_ls',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_mkdir': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_mkdir',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_mv': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_mv',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_read': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_read',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_rm': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_rm',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_stat': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_stat',
                                    'ipfspy.ipfshttpapi.IPFSApi.mfs_write': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.mfs_write',
                                    'ipfspy.ipfshttpapi.IPFSApi.pin_add': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.pin_add',
                                    'ipfspy.ipfshttpapi.IPFSApi.pin_ls': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.pin_ls',
                                    'ipfspy.ipfshttpapi.IPFSApi.pin_rm': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.pin_rm',
                                    'ipfspy.ipfshttpapi.IPFSApi.rpin_add': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.rpin_add',
                                    'ipfspy.ipfshttpapi.IPFSApi.rpin_ls': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.rpin_ls',
                                    'ipfspy.ipfshttpapi.IPFSApi.rpin_rm': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.rpin_rm',
                                    'ipfspy.ipfshttpapi.IPFSApi.rspin_add': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.rspin_add',
                                    'ipfspy.ipfshttpapi.IPFSApi.rspin_ls': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.rspin_ls',
                                    'ipfspy.ipfshttpapi.IPFSApi.rspin_rm': 'https://algoveraai.github.io/ipfspy/ipfshttpapi.html#ipfsapi.rspin_rm'},
            'ipfspy.pinataapi': { 'ipfspy.pinataapi.edit_metadata': 'https://algoveraai.github.io/ipfspy/pinataapi.html#edit_metadata',
                                  'ipfspy.pinataapi.generate_apikey': 'https://algoveraai.github.io/ipfspy/pinataapi.html#generate_apikey',
                                  'ipfspy.pinataapi.get_datausage': 'https://algoveraai.github.io/ipfspy/pinataapi.html#get_datausage',
                                  'ipfspy.pinataapi.get_pinned_files': 'https://algoveraai.github.io/ipfspy/pinataapi.html#get_pinned_files',
                                  'ipfspy.pinataapi.get_pinned_jobs': 'https://algoveraai.github.io/ipfspy/pinataapi.html#get_pinned_jobs',
                                  'ipfspy.pinataapi.list_apikeys': 'https://algoveraai.github.io/ipfspy/pinataapi.html#list_apikeys',
                                  'ipfspy.pinataapi.pin': 'https://algoveraai.github.io/ipfspy/pinataapi.html#pin',
                                  'ipfspy.pinataapi.revoke_apikey': 'https://algoveraai.github.io/ipfspy/pinataapi.html#revoke_apikey',
                                  'ipfspy.pinataapi.unpin': 'https://algoveraai.github.io/ipfspy/pinataapi.html#unpin',
                                  'ipfspy.pinataapi.upload_file': 'https://algoveraai.github.io/ipfspy/pinataapi.html#upload_file',
                                  'ipfspy.pinataapi.upload_jsonfile': 'https://algoveraai.github.io/ipfspy/pinataapi.html#upload_jsonfile'},
            'ipfspy.utils': { 'ipfspy.utils.GATEWAY_MAP': 'https://algoveraai.github.io/ipfspy/utils.html#gateway_map',
                              'ipfspy.utils.IPFSGateway': 'https://algoveraai.github.io/ipfspy/utils.html#ipfsgateway',
                              'ipfspy.utils.IPFSGateway.apipost': 'https://algoveraai.github.io/ipfspy/utils.html#ipfsgateway.apipost',
                              'ipfspy.utils.IPFSGateway.get': 'https://algoveraai.github.io/ipfspy/utils.html#ipfsgateway.get',
                              'ipfspy.utils.IPFSGateway.get_state': 'https://algoveraai.github.io/ipfspy/utils.html#ipfsgateway.get_state',
                              'ipfspy.utils.IPFSGateway.head': 'https://algoveraai.github.io/ipfspy/utils.html#ipfsgateway.head',
                              'ipfspy.utils.parse_error_message': 'https://algoveraai.github.io/ipfspy/utils.html#parse_error_message',
                              'ipfspy.utils.parse_response': 'https://algoveraai.github.io/ipfspy/utils.html#parse_response'}}}