# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"parse_response": "00_utils.ipynb",
         "parse_error_message": "00_utils.ipynb",
         "GATEWAY_MAP": "00_utils.ipynb",
         "IPFSGateway": "00_utils.ipynb",
         "IPFSApi": "01_ipfshttpapi.ipynb",
         "DownloadDir": "01_ipfshttpapi.ipynb",
         "est_get_viewer": "02_estuaryapi.ipynb",
         "list_pins": "02_estuaryapi.ipynb",
         "add_pin": "02_estuaryapi.ipynb",
         "get_pin": "02_estuaryapi.ipynb",
         "replace_pin": "02_estuaryapi.ipynb",
         "remove_pin": "02_estuaryapi.ipynb",
         "create_coll": "02_estuaryapi.ipynb",
         "add_content": "02_estuaryapi.ipynb",
         "list_colls": "02_estuaryapi.ipynb",
         "list_coll_content": "02_estuaryapi.ipynb",
         "list_content_path": "02_estuaryapi.ipynb",
         "add_content_path": "02_estuaryapi.ipynb",
         "add_key": "02_estuaryapi.ipynb",
         "add_data": "02_estuaryapi.ipynb",
         "add_cid": "02_estuaryapi.ipynb",
         "add_car": "02_estuaryapi.ipynb",
         "make_deal": "02_estuaryapi.ipynb",
         "view_data_cid": "02_estuaryapi.ipynb",
         "list_data": "02_estuaryapi.ipynb",
         "list_deals": "02_estuaryapi.ipynb",
         "get_deal_status": "02_estuaryapi.ipynb",
         "get_node_stats": "02_estuaryapi.ipynb",
         "get_deal_data": "02_estuaryapi.ipynb",
         "get_miner_ask": "02_estuaryapi.ipynb",
         "get_failure_logs": "02_estuaryapi.ipynb",
         "get_deal_logs": "02_estuaryapi.ipynb",
         "get_provider_stats": "02_estuaryapi.ipynb",
         "list_providers": "02_estuaryapi.ipynb",
         "get_data": "02_estuaryapi.ipynb",
         "generate_apikey": "03_pinataapi.ipynb",
         "list_apikeys": "03_pinataapi.ipynb",
         "revoke_apikey": "03_pinataapi.ipynb",
         "upload_file": "03_pinataapi.ipynb",
         "upload_jsonfile": "03_pinataapi.ipynb",
         "pin": "03_pinataapi.ipynb",
         "unpin": "03_pinataapi.ipynb",
         "edit_metadata": "03_pinataapi.ipynb",
         "get_pinned_jobs": "03_pinataapi.ipynb",
         "get_pinned_files": "03_pinataapi.ipynb",
         "get_datausage": "03_pinataapi.ipynb"}

modules = ["utils.py",
           "ipfshttpapi.py",
           "estuaryapi.py",
           "pinataapi.py"]

doc_url = "algoveraai.github.io/ipfspy/"

git_url = "https://github.com/AlgoveraAI/ipfspy/tree/master/"

def custom_doc_links(name): return None
